@@ -150,6 +150,11 @@ class BrowserBridge(DatabaseMixin, Bridge):
         self.driver.focus(element)
 
     def set_window_height(self, height):
+        self.logger.debug(
+            "Content sizes: %s (height) x %s (width)",
+            height,
+            self.window.DEFAULTS["width"],
+        )
         local_width = self.window.DEFAULTS["width"]
         local_width = local_width + 20 if sys.platform == "win32" else local_width
         local_height = height + 20 if sys.platform == "win32" else height
@@ -170,4 +175,5 @@ class BrowserBridge(DatabaseMixin, Bridge):
     @traceback
     def save(self, name, locator):
         self.ctx.database.load()
+        self.logger.info("Saving %s as locator: %s", name, locator)
         return super().save(name, locator)
